@@ -30,8 +30,8 @@
  * Tests the `SubarrayPartitioner` class for sparse arrays.
  */
 
-#include "test/src/helpers.h"
-#include "test/src/vfs_helpers.h"
+#include "test/support/src/helpers.h"
+#include "test/support/src/vfs_helpers.h"
 #include "tiledb/sm/c_api/tiledb_struct_def.h"
 #include "tiledb/sm/subarray/subarray_partitioner.h"
 
@@ -2283,9 +2283,7 @@ TEST_CASE_METHOD(
   // Check unsplittable
   tiledb::sm::Subarray subarray(
       array->array_.get(), layout, &g_helper_stats, g_helper_logger());
-  Range r;
-  r.set_str_range("bb", "bb");
-  subarray.add_range(0, std::move(r), true);
+  CHECK(subarray.add_range(0, Range("bb", "bb"), true).ok());
   ThreadPool tp(4);
   Config config;
   SubarrayPartitioner partitioner(
@@ -2313,7 +2311,7 @@ TEST_CASE_METHOD(
   auto partition = partitioner.current();
   CHECK(partition.range_num() == 1);
   const Range* range = nullptr;
-  partition.get_range(0, 0, &range);
+  CHECK(partition.get_range(0, 0, &range).ok());
   CHECK(range != nullptr);
   CHECK(range->start_str() == std::string("bb", 2));
   CHECK(range->end_str() == std::string("bb", 2));
@@ -2321,8 +2319,7 @@ TEST_CASE_METHOD(
   // Check full
   tiledb::sm::Subarray subarray_full(
       array->array_.get(), layout, &g_helper_stats, g_helper_logger());
-  r.set_str_range("a", "bb");
-  subarray_full.add_range(0, std::move(r), true);
+  CHECK(subarray_full.add_range(0, Range("a", "bb"), true).ok());
   SubarrayPartitioner partitioner_full(
       &config,
       subarray_full,
@@ -2341,7 +2338,7 @@ TEST_CASE_METHOD(
   CHECK(!unsplittable);
   partition = partitioner_full.current();
   CHECK(partition.range_num() == 1);
-  partition.get_range(0, 0, &range);
+  CHECK(partition.get_range(0, 0, &range).ok());
   CHECK(range != nullptr);
   CHECK(range->start_str() == std::string("a", 1));
   CHECK(range->end_str() == std::string("bb", 2));
@@ -2349,8 +2346,7 @@ TEST_CASE_METHOD(
   // Check split
   tiledb::sm::Subarray subarray_split(
       array->array_.get(), layout, &g_helper_stats, g_helper_logger());
-  r.set_str_range("a", "bb");
-  subarray_split.add_range(0, std::move(r), true);
+  CHECK(subarray_split.add_range(0, Range("a", "bb"), true).ok());
   SubarrayPartitioner partitioner_split(
       &config,
       subarray_split,
@@ -2370,7 +2366,7 @@ TEST_CASE_METHOD(
   CHECK(!unsplittable);
   partition = partitioner_split.current();
   CHECK(partition.range_num() == 1);
-  partition.get_range(0, 0, &range);
+  CHECK(partition.get_range(0, 0, &range).ok());
   CHECK(range != nullptr);
   CHECK(range->start_str() == std::string("a", 1));
   CHECK(range->end_str() == std::string("a\x7F", 2));
@@ -2378,7 +2374,7 @@ TEST_CASE_METHOD(
   CHECK(!unsplittable);
   partition = partitioner_split.current();
   CHECK(partition.range_num() == 1);
-  partition.get_range(0, 0, &range);
+  CHECK(partition.get_range(0, 0, &range).ok());
   CHECK(range != nullptr);
   CHECK(range->start_str() == std::string("b", 1));
   CHECK(range->end_str() == std::string("bb", 2));
@@ -2387,8 +2383,7 @@ TEST_CASE_METHOD(
   // Check no split 2 MBRs
   tiledb::sm::Subarray subarray_no_split(
       array->array_.get(), layout, &g_helper_stats, g_helper_logger());
-  r.set_str_range("bb", "cc");
-  subarray_no_split.add_range(0, std::move(r), true);
+  CHECK(subarray_no_split.add_range(0, Range("bb", "cc"), true).ok());
   SubarrayPartitioner partitioner_no_split(
       &config,
       subarray_no_split,
@@ -2409,7 +2404,7 @@ TEST_CASE_METHOD(
   CHECK(!unsplittable);
   partition = partitioner_no_split.current();
   CHECK(partition.range_num() == 1);
-  partition.get_range(0, 0, &range);
+  CHECK(partition.get_range(0, 0, &range).ok());
   CHECK(range != nullptr);
   CHECK(range->start_str() == std::string("bb", 2));
   CHECK(range->end_str() == std::string("cc", 2));
@@ -2417,8 +2412,7 @@ TEST_CASE_METHOD(
   // Check split 2 MBRs
   tiledb::sm::Subarray subarray_split_2(
       array->array_.get(), layout, &g_helper_stats, g_helper_logger());
-  r.set_str_range("bb", "cc");
-  subarray_split_2.add_range(0, std::move(r), true);
+  CHECK(subarray_split_2.add_range(0, Range("bb", "cc"), true).ok());
   SubarrayPartitioner partitioner_split_2(
       &config,
       subarray_split_2,
@@ -2439,7 +2433,7 @@ TEST_CASE_METHOD(
   CHECK(!unsplittable);
   partition = partitioner_split_2.current();
   CHECK(partition.range_num() == 1);
-  partition.get_range(0, 0, &range);
+  CHECK(partition.get_range(0, 0, &range).ok());
   CHECK(range != nullptr);
   CHECK(range->start_str() == std::string("bb", 2));
   CHECK(range->end_str() == std::string("b\x7F", 2));
@@ -2447,7 +2441,7 @@ TEST_CASE_METHOD(
   CHECK(!unsplittable);
   partition = partitioner_split_2.current();
   CHECK(partition.range_num() == 1);
-  partition.get_range(0, 0, &range);
+  CHECK(partition.get_range(0, 0, &range).ok());
   CHECK(range != nullptr);
   CHECK(range->start_str() == std::string("c", 1));
   CHECK(range->end_str() == std::string("cc", 2));
@@ -2556,9 +2550,7 @@ TEST_CASE_METHOD(
 
   tiledb::sm::Subarray subarray(
       array->array_.get(), layout, &g_helper_stats, g_helper_logger());
-  Range r;
-  r.set_str_range("cc", "ccd");
-  subarray.add_range(0, std::move(r), true);
+  CHECK(subarray.add_range(0, Range("cc", "ccd"), true).ok());
   ThreadPool tp(4);
   Config config;
   SubarrayPartitioner partitioner(
