@@ -159,152 +159,6 @@ class Query {
   /*                 API               */
   /* ********************************* */
 
-  /**
-   * Adds a range to the (read/write) query on the input dimension by index,
-   * in the form of (start, end, stride).
-   * The range components must be of the same type as the domain type of the
-   * underlying array.
-   */
-  Status add_range(
-      unsigned dim_idx, const void* start, const void* end, const void* stride);
-
-  /**
-   * Adds a variable-sized range to the (read/write) query on the input
-   * dimension by index, in the form of (start, end).
-   */
-  Status add_range_var(
-      unsigned dim_idx,
-      const void* start,
-      uint64_t start_size,
-      const void* end,
-      uint64_t end_size);
-
-  /** Retrieves the number of ranges of the subarray for the given dimension
-   * index. */
-  Status get_range_num(unsigned dim_idx, uint64_t* range_num) const;
-
-  /**
-   * Retrieves a range from a dimension index in the form (start, end, stride).
-   *
-   * @param dim_idx The dimension to retrieve the range from.
-   * @param range_idx The id of the range to retrieve.
-   * @param start The range start to retrieve.
-   * @param end The range end to retrieve.
-   * @param stride The range stride to retrieve.
-   * @return Status
-   */
-  Status get_range(
-      unsigned dim_idx,
-      uint64_t range_idx,
-      const void** start,
-      const void** end,
-      const void** stride) const;
-
-  /**
-   * Retrieves a range's sizes for a variable-length dimension index
-   *
-   * @param dim_idx The dimension to retrieve the range from.
-   * @param range_idx The id of the range to retrieve.
-   * @param start_size range start size in bytes
-   * @param end_size range end size in bytes
-   * @return Status
-   */
-  Status get_range_var_size(
-      unsigned dim_idx,
-      uint64_t range_idx,
-      uint64_t* start_size,
-      uint64_t* end_size) const;
-
-  /**
-   * Retrieves a range from a variable-length dimension index in the form
-   * (start, end).
-   *
-   * @param dim_idx The dimension to retrieve the range from.
-   * @param range_idx The id of the range to retrieve.
-   * @param start The range start to retrieve.
-   * @param end The range end to retrieve.
-   * @return Status
-   */
-  Status get_range_var(
-      unsigned dim_idx, uint64_t range_idx, void* start, void* end) const;
-
-  /**
-   * Adds a range to the (read/write) query on the input dimension by name,
-   * in the form of (start, end, stride).
-   * The range components must be of the same type as the domain type of the
-   * underlying array.
-   */
-
-  Status add_range_by_name(
-      const std::string& dim_name,
-      const void* start,
-      const void* end,
-      const void* stride);
-
-  /**
-   * Adds a variable-sized range to the (read/write) query on the input
-   * dimension by name, in the form of (start, end).
-   */
-  Status add_range_var_by_name(
-      const std::string& dim_name,
-      const void* start,
-      uint64_t start_size,
-      const void* end,
-      uint64_t end_size);
-
-  /** Retrieves the number of ranges of the subarray for the given dimension
-   * name. */
-  Status get_range_num_from_name(
-      const std::string& dim_name, uint64_t* range_num) const;
-
-  /**
-   * Retrieves a range from a dimension name in the form (start, end, stride).
-   *
-   * @param dim_name The dimension to retrieve the range from.
-   * @param range_idx The id of the range to retrieve.
-   * @param start The range start to retrieve.
-   * @param end The range end to retrieve.
-   * @param stride The range stride to retrieve.
-   * @return Status
-   */
-  Status get_range_from_name(
-      const std::string& dim_name,
-      uint64_t range_idx,
-      const void** start,
-      const void** end,
-      const void** stride) const;
-
-  /**
-   * Retrieves a range's sizes for a variable-length dimension name
-   *
-   * @param dim_name The dimension name to retrieve the range from.
-   * @param range_idx The id of the range to retrieve.
-   * @param start_size range start size in bytes
-   * @param end_size range end size in bytes
-   * @return Status
-   */
-  Status get_range_var_size_from_name(
-      const std::string& dim_name,
-      uint64_t range_idx,
-      uint64_t* start_size,
-      uint64_t* end_size) const;
-
-  /**
-   * Retrieves a range from a variable-length dimension name in the form (start,
-   * end).
-   *
-   * @param dim_name The dimension name to retrieve the range from.
-   * @param range_idx The id of the range to retrieve.
-   * @param start The range start to retrieve.
-   * @param end The range end to retrieve.
-   * @return Status
-   */
-  Status get_range_var_from_name(
-      const std::string& dim_name,
-      uint64_t range_idx,
-      void* start,
-      void* end) const;
-
   /**
    * Gets the estimated result size (in bytes) for the input fixed-sized
    * attribute/dimension.
@@ -440,26 +294,6 @@ class Query {
   Status get_data_buffer(
       const char* name, void** buffer, uint64_t** buffer_size) const;
 
-  /**
-   * Retrieves the data buffer of a fixed or variable-sized dimension label.
-   *
-   * @param name The name of the the label.
-   * @param buffer The buffer to be retrieved.
-   * @param buffer_size The size of the buffer.
-   */
-  void get_label_data_buffer(
-      const std::string& name, void** buffer, uint64_t** buffer_size) const;
-
-  /**
-   * Retrieves the offset buffer for a variable-sized dimension label.
-   *
-   * @param name The name of the label.
-   * @param buffer The buffer to be retrieved.
-   * @param buffer_size The size of the buffer.
-   */
-  void get_label_offsets_buffer(
-      const std::string& name, uint64_t** buffer, uint64_t** buffer_size) const;
-
   /**
    * Retrieves the offset buffer for a var-sized attribute/dimension.
    *
@@ -685,36 +519,6 @@ class Query {
   void set_dimension_label_buffer(
       const std::string& name, const QueryBuffer& buffer);
 
-  /**
-   * Sets the label data buffer for fixed or variable sized dimension labels.
-   *
-   * @param name The name of the dimension label to set the data buffer for.
-   * @param buffer The buffer for the data.
-   * @param buffer_size The size of the data.
-   * @param check_null_buffers If ``true`` verify buffer and buffersize are not
-   *     nullptrs.
-   */
-  void set_label_data_buffer(
-      const std::string& name,
-      void* const buffer,
-      uint64_t* const buffer_size,
-      const bool check_null_buffers = true);
-
-  /**
-   * Sets the label offsets buffer for variable sized dimension labels.
-   *
-   * @param name The name of the dimension label to set the offsets buffer for.
-   * @param buffer_offsets The buffer for offsets for the variable size data.
-   * @param buffer_offsets_size The size of the offsets buffer.
-   * @param check_null_buffers If ``true`` verify buffer and buffersize are not
-   *     nullptrs.
-   */
-  void set_label_offsets_buffer(
-      const std::string& name,
-      uint64_t* const buffer_offsets,
-      uint64_t* const buffer_offsets_size,
-      const bool check_null_buffers = true);
-
   /**
    * Sets the offset buffer for a var-sized attribute/dimension.
    *
@@ -955,13 +759,8 @@ class Query {
    * the entire domain.
    *
    * @param subarray The subarray to be set.
-   * @return Status
-   *
-   * @note Setting a subarray for sparse arrays, or for dense arrays
-   *     when performing unordered (sparse) writes, has no effect
-   *     (will be ingnored).
    */
-  Status set_subarray(const void* subarray);
+  void set_subarray(const void* subarray);
 
   /** Returns the query subarray. */
   const Subarray* subarray() const;
@@ -970,12 +769,8 @@ class Query {
    * Sets the query subarray.
    *
    * @param subarray The subarray to be set.
-   * @return Status
-   *
-   * @note Calling set_subarray for sparse arrays, or for dense arrays
-   *     when performing unordered (sparse) writes, has no effect.
    */
-  Status set_subarray(const tiledb::sm::Subarray& subarray);
+  void set_subarray(const tiledb::sm::Subarray& subarray);
 
   /** Sets the query subarray, without performing any checks. */
   Status set_subarray_unsafe(const Subarray& subarray);
@@ -983,6 +778,15 @@ class Query {
   /** Sets the query subarray, without performing any checks. */
   Status set_subarray_unsafe(const NDRange& subarray);
 
+  /**
+   * Sets the query subarray without performing any checks.
+   *
+   * Used for deserialize dense writes.
+   *
+   * @param subarray The subarray to be set.
+   */
+  void set_subarray_unsafe(const void* subarray);
+
   /** Submits the query to the storage manager. */
   Status submit();
 
