@@ -33,6 +33,7 @@
 #define TILEDB_QUERY_DOMAIN_BUFFER_H
 
 #include <new>
+
 #include "../query_buffer.h"
 #include "tiledb/sm/array_schema/array_schema.h"
 #include "tiledb/sm/array_schema/dimension.h"
@@ -137,11 +138,12 @@ class SingleCoord {
       memcpy(coords_[d].data(), dv.content(), sizes_[d]);
 
       if (var_size) {
-        qb_[d].set_offsets_buffer(
-            &single_offset_[0], &sizes_[schema.dim_num()]);
-        qb_[d].set_data_var_buffer(coords_[d].data(), &sizes_[d]);
+        throw_if_not_ok(qb_[d].set_offsets_buffer(
+            &single_offset_[0], &sizes_[schema.dim_num()]));
+        throw_if_not_ok(
+            qb_[d].set_data_var_buffer(coords_[d].data(), &sizes_[d]));
       } else {
-        qb_[d].set_data_buffer(coords_[d].data(), &sizes_[d]);
+        throw_if_not_ok(qb_[d].set_data_buffer(coords_[d].data(), &sizes_[d]));
       }
     }
   }
@@ -172,11 +174,13 @@ class SingleCoord {
       memcpy(coords_[d].data(), coords[d].data(), sizes[d]);
 
       if (var_size) {
-        qb_[d].set_offsets_buffer(
-            single_offset_.data(), sizes_.data() + schema.dim_num());
-        qb_[d].set_data_var_buffer(coords_[d].data(), sizes_.data() + d);
+        throw_if_not_ok(qb_[d].set_offsets_buffer(
+            single_offset_.data(), sizes_.data() + schema.dim_num()));
+        throw_if_not_ok(
+            qb_[d].set_data_var_buffer(coords_[d].data(), sizes_.data() + d));
       } else {
-        qb_[d].set_data_buffer(coords_[d].data(), sizes_.data() + d);
+        throw_if_not_ok(
+            qb_[d].set_data_buffer(coords_[d].data(), sizes_.data() + d));
       }
     }
   }
@@ -263,6 +267,23 @@ class DomainBuffersView : public detail::DomainBuffersTypes {
     }
   }
 
+  /**
+   * Constructor
+   *
+   * @param domain the domain of an open array
+   * @param buffers a buffer map for each dimension of the domain
+   */
+  DomainBuffersView(
+      const Domain& domain,
+      const std::unordered_map<std::string, QueryBuffer>& buffers)
+      : qb_(domain.dim_num()) {
+    auto n_dimensions{domain.dim_num()};
+    for (decltype(n_dimensions) i = 0; i < n_dimensions; ++i) {
+      const auto& name{domain.dimension_ptr(i)->name()};
+      qb_[i] = &buffers.at(name);
+    }
+  }
+
   /**
    * Constructor
    *
@@ -280,6 +301,20 @@ class DomainBuffersView : public detail::DomainBuffersTypes {
     }
   }
 
+  /**
+   * Constructor
+   *
+   * @param domain the domain of an open array
+   * @param buffers a buffer vector for each dimension of the domain
+   */
+  DomainBuffersView(const Domain& domain, std::vector<QueryBuffer>& qb_vector)
+      : qb_(domain.dim_num()) {
+    auto n_dimensions{domain.dim_num()};
+    for (decltype(n_dimensions) i = 0; i < n_dimensions; ++i) {
+      qb_[i] = &qb_vector[i];
+    }
+  }
+
   /**
    * Accessor to wrapped container.
    */
