@@ -52,7 +52,7 @@ class WriterTile {
 
   WriterTile(
       const ArraySchema& array_schema,
-      const bool has_coords,
+      const uint64_t cell_num_per_tile,
       const bool var_size,
       const bool nullable,
       const uint64_t cell_size,
@@ -192,7 +192,9 @@ class WriterTile {
    *
    * @param size Final size.
    */
-  inline void final_size(uint64_t size) {
+  inline void set_final_size(uint64_t size) {
+    cell_num_ = size;
+
     if (var_tile_.has_value()) {
       fixed_tile_.set_size(size * constants::cell_var_offset_size);
     } else {
@@ -210,18 +212,13 @@ class WriterTile {
    * @return Cell number.
    */
   inline uint64_t cell_num() const {
-    return fixed_tile_.cell_num();
+    return cell_num_;
   }
 
   /** Swaps the contents (all field values) of this tile with the given tile. */
   void swap(WriterTile& tile);
 
  private:
-  /* ********************************* */
-  /*        PRIVATE CONSTRUCTOR        */
-  /* ********************************* */
-  WriterTile() = default;
-
   /* ********************************* */
   /*         PRIVATE ATTRIBUTES        */
   /* ********************************* */
@@ -261,6 +258,9 @@ class WriterTile {
 
   /** Count of null values. */
   uint64_t null_count_;
+
+  /** Cell num. */
+  uint64_t cell_num_;
 };
 
 }  // namespace sm
